@@ -24,7 +24,7 @@ def pytest_configure(config):
         DATABASES={
             "default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}
         },
-        INSTALLED_APPS=["gdaps", "tests.plugins.plugin1.apps.Plugin1Config"],
+        INSTALLED_APPS=["gdaps.core", "tests.plugins.plugin1"],
         PLUGIN1={"OVERRIDE": 20},
     )
 
