@@ -14,8 +14,6 @@ def test_plugin1():
 
 
 def test_plugin_meta():
-    from django.apps import apps
-
     apps = PluginManager.plugins()
     assert len(apps) != 0
     for app_config in apps:
@@ -25,7 +23,7 @@ def test_plugin_meta():
 
 @pytest.mark.django_db
 def test_plugin_initialize_cmd():
-    from gdaps.models import GdapsPlugin
+    from gdaps.core.models import GdapsPlugin
 
     # first, no plugins are installed.
     with pytest.raises(ObjectDoesNotExist):
